@@ -43,7 +43,8 @@ check_var <- function(vars, varn, varntype = NULL, dataset,
                       withperiod = TRUE, varnout = NULL, varname = NULL,
                       PSUs = NULL, country = NULL, countryX = NULL,
                       years = NULL, yearsX = NULL, periods = NULL,
-                      periodsX = NULL, ID_level1 = NULL, use.gender = FALSE){
+                      periodsX = NULL, ID_level1 = NULL, dX = "",
+                      use.gender = FALSE){
 
   N <- NULL
   if (varn %in%  c("g", "q") & (is.null(class(vars)) | any(class(vars) == "function"))) stop("'g' must be numeric", call. = FALSE)
@@ -76,7 +77,7 @@ check_var <- function(vars, varn, varntype = NULL, dataset,
       if (!withperiod & varn == "period") stop(paste0("'period' must be NULL for those data"), call. = FALSE)
       if(!is.null(dataset)) {
         dataset <- data.table(dataset)
-        if (min(vars %in% names(dataset)) != 1) stop(paste0("'", varn, "' does not exist in 'dataset'!"), call. = FALSE)
+        if (min(vars %in% names(dataset)) != 1) stop(paste0("'", varn, "' does not exist in 'dataset", dX, "'!"), call. = FALSE)
         if (min(vars %in% names(dataset)) == 1)  vars <- dataset[, vars, with = FALSE]}
 
       vars <- data.table(vars, check.names = check.names)
