@@ -276,7 +276,7 @@ vardom_othstr <- function(Y, H, H2, PSU, w_final,
 
 
   # Total estimation
-  Y_nov <- Z_nov <- .SD <- NULL
+  Y_nov <- Z_nov <- .SD <- confidence_level <- NULL
 
   hY <- data.table(Y1 * w_final)
   if (is.null(period)) { Y_nov <- hY[, lapply(.SD, sum, na.rm = TRUE), .SDcols = names(Y1)]
@@ -365,14 +365,14 @@ vardom_othstr <- function(Y, H, H2, PSU, w_final,
                          } else { all_result[, respondent_count := nhs$respondent_count]
                                   all_result[, pop_size := nhs$pop_size]} 
 
+  all_result[, confidence_level := confidence]
   variab <- c("respondent_count", "n_nonzero", "pop_size", "estim", "var", "se", 
               "rse", "cv", "absolute_margin_of_error", "relative_margin_of_error",
-              "CI_lower", "CI_upper", "var_srs_HT",  "var_cur_HT", 
+              "CI_lower", "CI_upper", "confidence_level", "var_srs_HT",  "var_cur_HT", 
               "var_srs_ca", "deff_sam", "deff_est", "deff")
 
   setkeyv(all_result, c("nr_names", names(Dom), names(period)))
   all_result <- all_result[, c("variable", names(Dom), names(period), variab), with = FALSE]
-
   list(lin_out = linratio_outp,
        res_out = res_outp,
        s2g = s2g,
